#
# db2_secured::controls::turn_off_remote_command_legacy_mode
#
# @summary The `DB2RCMD_LEGACY_MODE` registry variable determines whether the Db2 Remote Command Service runs with enhanced security or not.
# It is recommended that legacy mode not be enabled.
# This registry variable only applies to Db2 Servers running on Windows.
# 
# Rationale:
# 
# Legacy mode requires the Db2 service account to have privileges to impersonate the client account.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::turn_off_remote_command_legacy_mode: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::turn_off_remote_command_legacy_mode::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `turn_off_remote_command_legacy_mode` to the array value `db2_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.2
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::turn_off_remote_command_legacy_mode {
  db2_secured_setup { "turn_off_remote_command_legacy_mode on ${title}":
    ensure => 'present',
  }

  if $facts['kernel'] == 'Windows' {
    alert('Specified CIS control is not yet automatically enforced.')
  } else {
    debug('Specified CIS control is not applicable on current kernel')
  }
}
